@@ -18,6 +18,18 @@
 # USA.
 
 
-from .sensor import DatedState, HistoricalSensor
+import logging
 
-__all__ = ["DatedState", "HistoricalSensor"]
+from homeassistant.const import MAJOR_VERSION, MINOR_VERSION
+
+from .sensor import HistoricalSensor, PollUpdateMixin
+from .state import HistoricalState
+
+LOGGER = logging.getLogger(__name__)
+
+if not (MAJOR_VERSION >= 2023 and MINOR_VERSION >= 2):
+    msg = "Required homeassistant version >=2023.2.0"
+    LOGGER.debug(msg)
+    raise SystemError(msg)
+
+__all__ = ["HistoricalSensor", "HistoricalState", "PollUpdateMixin"]
